## Dataset Attribution
This dataset was created by Maarten Sap & Saadia Gabriel and is licensed under the Creative Commons Attribution 4.0 International.

- Original Source: [maartensap.com](https://maartensap.com/social-bias-frames/)
- License: [https://creativecommons.org/licenses/by/4.0/](https://creativecommons.org/licenses/by/4.0/)
- Changes Made: `extraction.py` from this folder was used to filter and edit the dataset.
